<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Copiando a cor %1 para a área de  transferência</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>O Selecionador Deepin é uma ferramenta fácil e rápida para capturar cores na tela. Códigos RGB e HEX são obtidos com um clique e salvos automaticamente para a área de transferência.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>Deepin Picker</source>
        <translation>Selecionador Deepin</translation>
    </message>
</context>
</TS>
